input[type="month"] {
    font-family: Arial, sans-serif;
    width: 80%;
    padding: 10px;
    margin-bottom: 15px;
    background-color: #f9f9f9;
    background-image: linear-gradient(to bottom, #f9f9f9, #e9e9e9);
    border: none;
    box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    font-size: 16px;
    color: #333;
    border-radius: 5px;
  }
  label {
    padding-bottom: 20px;
  }
  input[type="month"]:focus {
    outline: none;
    background-color: #fff;
    box-shadow: 0 0 5px rgba(66, 133, 244, 0.5);
  }
  

